@@ -18,9 +18,12 @@
 #include "lang_pascal.h"
 #include "lang_java.h"
 #include "lang_perl.h"
+#include "lang_pike.h"
 #include "lang_text.h"
 #include "lang_verilog.h"
 #include "options.h"
+#include "utils.h"
+
 #include "language.h"
 
 boolean restart_language;
@@ -34,6 +37,7 @@ char *language_list =
 "  sh      shell\n"
 "  pascal  Pascal\n"
 "  perl    Perl\n"
+"  pike    Pike\n"
 "  java    Java\n"
 "  text    plain text\n"
 "  list    compiler or assembler listing file\n"
@@ -52,6 +56,7 @@ typedef enum {
   SHELL,
   PASCAL,
   PERL,
+  PIKE,
   LIST,
   TEXT,
   JAVA,
@@ -95,12 +100,15 @@ set_language_default(char *value)
   else if (strcmp(value,"sh") == 0)     language = SHELL;
   else if (strcmp(value,"pascal") == 0) language = PASCAL;
   else if (strcmp(value,"perl") == 0)   language = PERL;
+  else if (strcmp(value,"pike") == 0)   language = PIKE;
   else if (strcmp(value,"java") == 0)   language = JAVA;
   else if (strcmp(value,"text") == 0)   language = TEXT;
   else if (strcmp(value,"list") == 0)   language = LIST;
   else if (strcmp(value,"pseudoc") == 0)language = PSEUDOC;
-  else
-    abort();
+  else {
+    fprintf(stderr, gettext(CMD_NAME ": unrecognized language type: %s\n"), value);
+    exit(1);
+  }
 }
 /******************************************************************************
  * Function:
@@ -123,26 +131,38 @@ filename_to_language(char *filename)
   languages retval;
   char *suffix;
 
-  if ((suffix = strrchr(filename,'.')) == (char *)0) retval = TEXT;
-  else if (strcmp(suffix,".c") == 0) retval = C;
-  else if (strcmp(suffix,".v") == 0) retval = VERILOG;
-  else if (strcmp(suffix,".h") == 0) retval = C;
-  else if (strcmp(suffix,".cxx") == 0) retval = CXX;
-  else if (strcmp(suffix,".cpp") == 0) retval = CXX;
-  else if (strcmp(suffix,".cc") == 0) retval = CXX;
-  else if (strcmp(suffix,".C") == 0) retval = CXX;   /* James Card */
-  else if (strcmp(suffix,".hpp") == 0) retval = CXX;
-  else if (strcmp(suffix,".H") == 0) retval = CXX;   /* James Card */
-  else if (strcmp(suffix,".pc") == 0) retval = PSEUDOC;
-  else if (strcmp(suffix,".ph") == 0) retval = PSEUDOC;
-  else if (strcmp(suffix,".rep") == 0) retval = REPORT;
-  else if (strcmp(suffix,".sh") == 0) retval = SHELL;
-  else if (strcmp(suffix,".pas") == 0) retval = PASCAL;
-  else if (strcmp(suffix,".pl") == 0) retval = PERL;
-  else if (strcmp(suffix,".pm") == 0) retval = PERL;
-  else if (strcmp(suffix,".java") == 0) retval = JAVA;
-  else if (strcmp(suffix,".lst") == 0) retval = LIST;
-  else retval = TEXT;
+  dm('l',2,"Finding language for filename %s\n",filename);
+  if ((suffix = strrchr(filename,'.')) == (char *)0)
+    {
+      retval = TEXT;
+    }
+  else
+    {
+      dm('l',2,"Finding language for suffix %s\n",suffix);
+
+      if (strcmp(suffix,".c") == 0) retval = C;
+      else if (strcmp(suffix,".v") == 0) retval = VERILOG;
+      else if (strcmp(suffix,".h") == 0) retval = C;
+      else if (strcmp(suffix,".cxx") == 0) retval = CXX;
+      else if (strcmp(suffix,".cpp") == 0) retval = CXX;
+      else if (strcmp(suffix,".cc") == 0) retval = CXX;
+      else if (strcmp(suffix,".C") == 0) retval = CXX;   /* James Card */
+      else if (strcmp(suffix,".hpp") == 0) retval = CXX;
+      else if (strcmp(suffix,".H") == 0) retval = CXX;   /* James Card */
+      else if (strcmp(suffix,".pc") == 0) retval = PSEUDOC;
+      else if (strcmp(suffix,".ph") == 0) retval = PSEUDOC;
+      else if (strcmp(suffix,".rep") == 0) retval = REPORT;
+      else if (strcmp(suffix,".sh") == 0) retval = SHELL;
+      else if (strcmp(suffix,".pas") == 0) retval = PASCAL;
+      else if (strcmp(suffix,".pl") == 0) retval = PERL;
+      else if (strcmp(suffix,".pm") == 0) retval = PERL;
+      else if (strcmp(suffix,".pk") == 0) retval = PIKE;
+      else if (strcmp(suffix,".java") == 0) retval = JAVA;
+      else if (strcmp(suffix,".lst") == 0) retval = LIST;
+      else retval = TEXT;
+    }
+
+  dm('l',2,"Language is %d\n",retval);
 
   return retval;
 }
@@ -167,6 +187,7 @@ language_defaults(char *filename)
     case SHELL: 	retval = lang_sh_defaults; 	break;
     case PASCAL: 	retval = lang_pascal_defaults; 	break;
     case PERL: 		retval = lang_perl_defaults; 	break;
+    case PIKE: 		retval = lang_pike_defaults; 	break;
     case JAVA: 		retval = lang_java_defaults; 	break;
     case TEXT:	 	retval = lang_text_defaults; 	break;
     case LIST: 		retval = lang_list_defaults; 	break;
@@ -204,6 +225,7 @@ set_get_char(char *filename)
     case SHELL:		get_char = get_sh_char;		break;
     case PASCAL:	get_char = get_pascal_char;	break;
     case PERL:		get_char = get_perl_char;	break;
+    case PIKE:		get_char = get_pike_char;	break;
     case JAVA:		get_char = get_java_char;	break;
     case TEXT:		get_char = get_text_char;	break;
     case LIST:		get_char = get_text_char;	break;
